@echo off
:: =============================================================================
::  File:   LANGUAGE.BAT
::  Author: TCD
::  Date:   7/24/2000
:: =============================================================================
::                                                                             
::                            Speedline Technologies                           
::                                16 Forge Park                                
::                              Franklin, MA 02038                             
::                                (508) 520-6999                               
::                                                                             
::                          Copyright (c) 1988 - 2000.                         
::                                                                             
:: =============================================================================
::  Batch File Description:
::    INSTLANG.BAT and LANGUAGE.BAT which do the installation of language
::    support files are based on some AP batch files.  INSTLANG.BAT which is
::    called by INSTALL.BAT does the following:
::
::      1. Create a subdirectory off of 'C:\SPMV' for each language
::
::           C:\SPMV\English
::           C:\SPMV\French
::           C:\SPMV\German
::           C:\SPMV\Spanish
::
::      2. Install the language support files by executing the following
::         self-extracting archive language '.EXE' files:
::
::           A:\SPMV\English\English.exe
::           A:\SPMV\French\French.exe
::           A:\SPMV\German\German.exe
::           A:\SPMV\Spanish\Spanish.exe
::
::         The language '.RSC' file and '*.HLP' files are extracted into the
::         language subdirectories off of 'C:\SPMV'.
::
::      3. English is installed as the default language by the following:
::
::           Copy C:\SPMV\English\English.rsc C:\SPMV\Strings.rsc
::
::           Copy C:\SPMV\English\*.hlp C:\SPMV\Help
::
::      4. Call LANGUAGE.BAT which provides the ability to install the selected
::         language by the following:
::
::           Copy the language '.RSC' file to 'C:\SPMV\STRINGS.RSC'
::
::           Copy the language '*.HLP' files into 'C:\SPMV\HELP'
::
::      LANGUAGE.BAT is called by INSTLANG.BAT or can be invoked directly by
::      entering C:\SPMV\LANGUAGE.BAT on the command line.
::
::      The batch commands CHOICE and ERRORLEVEL require attention because the
::      selections be must evaluated by order going from the highest number down
::      to the lowest number.
::
::   
::  History:
::      7/24/2000   Initial Release   
::
:: 
:: =============================================================================

:: ------------------- Setup the environment variable - ldir ------------
set ldir=SPMV

:install_language

:: Verify that the destination directory exists
if not exist c:\%ldir%\nul goto dest_dir_err

cls
echo.
echo.
echo.
echo              Please choose the Language you wish to install:
echo.
echo                                1 - English
echo                                2 - French
echo                                3 - German
echo                                4 - Spanish
echo                                5 - Exit
echo.
choice /c12345 Choose one of these numbers: 
echo.

if errorlevel 5 goto skip
if errorlevel 4 goto spanish
if errorlevel 3 goto german
if errorlevel 2 goto french
if errorlevel 1 goto english


:: You shouldn't ever get here, but... In case of error just put in English - raw 12/15/00
goto english

:spanish
:: ------------------- Install Spanish ----------------------------------
if not exist c:\%ldir%\Spanish\nul         goto lang_dir_err
if not exist c:\%ldir%\Spanish\Spanish.rsc goto lang_file_err
if not exist c:\%ldir%\Spanish\*.hlp       goto hlp_file_err

copy c:\%ldir%\Spanish\Spanish.rsc         c:\%ldir%\Strings.rsc /y /v > null
copy c:\%ldir%\Spanish\*.hlp               c:\%ldir%\Help\*.hlp  /y /v > null

set lang=Spanish
goto lang_installed


:german
:: ------------------- Install German -----------------------------------
if not exist c:\%ldir%\German\nul          goto lang_dir_err
if not exist c:\%ldir%\German\German.rsc   goto lang_file_err
if not exist c:\%ldir%\German\*.hlp        goto hlp_file_err

copy c:\%ldir%\German\German.rsc           c:\%ldir%\Strings.rsc /y /v > null
copy c:\%ldir%\German\*.hlp                c:\%ldir%\help\*.hlp  /y /v > null

set lang=German
goto lang_installed


:french
:: ------------------- Install French -----------------------------------
if not exist c:\%ldir%\French\nul          goto lang_dir_err
if not exist c:\%ldir%\French\French.rsc   goto lang_file_err
if not exist c:\%ldir%\French\*.hlp        goto hlp_file_err

copy c:\%ldir%\French\French.rsc           c:\%ldir%\Strings.rsc /y /v > null
copy c:\%ldir%\French\*.hlp                c:\%ldir%\help\*.hlp  /y /v > null

set lang=French
goto lang_installed


:english
:: ------------------- Install English ----------------------------------
if not exist c:\%ldir%\English\nul         goto lang_dir_err
if not exist c:\%ldir%\English\English.rsc goto lang_file_err
if not exist c:\%ldir%\English\*.hlp       goto hlp_file_err

copy c:\%ldir%\English\English.rsc         c:\%ldir%\Strings.rsc /y /v > null
copy c:\%ldir%\English\*.hlp               c:\%ldir%\Help\*.hlp  /y /v > null

set lang=English
goto lang_installed


:dest_dir_err
cls
echo.
echo.
echo.
echo.
echo                      You can not install chosen Language!
echo.
echo                             SPM directory missing
echo.
echo             Contact Speedline Technologies Service Representative
echo.
echo.
pause
echo.
goto done

:lang_dir_err
cls
echo.
echo.
echo.
echo.
echo                      You can not install chosen Language!
echo.
echo                       SPM Language subdirectory missing
echo.
echo             Contact Speedline Technologies Service Representative
echo.
echo.
pause
echo.
cls
goto done

:lang_file_err
cls
echo.
echo.
echo.
echo.
echo                      You can not install chosen Language!
echo.
echo               Resource file in SPM Language subdirectory missing
echo.
echo             Contact Speedline Technologies Service Representative
echo.
echo.
pause
echo.
cls
cd c:\%ldir%
goto done

:hlp_file_err
cls
echo.
echo.
echo.
echo.
echo                      You can not install chosen Language!
echo.
echo                 Help files in SPM Language subdirectory missing
echo.
echo             Contact Speedline Technologies Service Representative
echo.
echo.
pause
echo.
cls
goto done

:skip
:: ------------------- Do Not Install a Language ------------------------
cls
echo.
echo.
echo.
echo          You choose not to install Language option on your machine
echo.
echo                  Setup will retain your default Language
echo.
choice /cyn   /T:Y,15   Please choose  Y - Exit, N - Back 
if errorlevel 2 goto install_language
if errorlevel 1 goto no_lang

:no_lang
echo.
goto done

:lang_installed
echo Language installed  --  %lang%
echo.
goto done

:done
:: ------------------- Delete the environment variables -----------------
set ldir=
set lang=
